@@ -9,14 +9,14 @@ echo
 echo -n "What is the version number (previous was $PREVIOUS)? "
 read VERSION
 
-echo
-echo "--- Setup ---"
-set -x
-pip install --upgrade readme-renderer
-pip install --upgrade twine
+#echo
+#echo "--- Setup ---"
+#set -x
+#pip install --upgrade readme-renderer
+#pip install --upgrade twine
 rm -rf build dist *.egg-info
 # git pull || true
-set +x
+#set +x
 
 echo
 echo "--- Setup ---"
